@@ -13,17 +13,15 @@
 
 package Pod::ParseLink;
 
-use 5.008;
+use 5.010;
 use strict;
 use warnings;
 
-use vars qw(@EXPORT @ISA $VERSION);
-
 use Exporter;
-@ISA    = qw(Exporter);
-@EXPORT = qw(parselink);
 
-$VERSION = '4.14';
+our @ISA = qw(Exporter);
+our @EXPORT = qw(parselink);
+our $VERSION = '5.00';
 
 ##############################################################################
 # Implementation
@@ -171,7 +169,7 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2001, 2008, 2009, 2014, 2018-2019 Russ Allbery <rra@cpan.org>
+Copyright 2001, 2008, 2009, 2014, 2018-2019, 2022 Russ Allbery <rra@cpan.org>
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
